Neural Network Utilities
========================

.. currentmodule:: kooplearn.nn

Score & Loss functions
----------------------

.. autofunction:: kooplearn.nn.functional.vamp_score

.. autofunction:: kooplearn.nn.functional.relaxed_projection_score

.. autofunction:: kooplearn.nn.functional.log_fro_metric_deformation_loss  


Linear algebra & miscellanea
----------------------------

.. autofunction:: kooplearn.nn.functional.sqrtmh
